@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2006,2007 Jimmy Gilles <jimmygilles@gmail.com>
- * Copyright (C) 2007,2008,2009,2010,2012,2013,2014 Rolf Eike Beer <kde@opensource.sf-tec.de>
+ * Copyright (C) 2007,2008,2009,2010,2012,2013,2014,2017
+ *               Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 
 /***************************************************************************
@@ -303,7 +304,7 @@ QString KgpgKey::strength() const
 
 uint KgpgKey::encryptionSize() const
 {
-	const KgpgKeySub *enc = Q_NULLPTR;
+	const KgpgKeySub *enc = nullptr;
 	// Get the first encryption subkey
 	foreach (const KgpgKeySub &k, *d->gpgsublist) {
 		if (k.type() & SKT_ENCRYPTION) {
@@ -311,18 +312,18 @@ uint KgpgKey::encryptionSize() const
 			// check if there is one that is not
 			if (k.trust() > TRUST_EXPIRED)
 				return k.size();
-			if (enc == Q_NULLPTR)
+			if (enc == nullptr)
 				enc = &k;
 		}
 	}
-	if (enc != Q_NULLPTR)
+	if (enc != nullptr)
 		return enc->size();
 	return 0;
 }
 
 QString KgpgKey::encryptionStrength() const
 {
-    const KgpgKeySub *enc = Q_NULLPTR;
+    const KgpgKeySub *enc = nullptr;
     // Get the first encryption subkey
     foreach (const KgpgKeySub &k, *d->gpgsublist) {
         if (k.type() & SKT_ENCRYPTION) {
@@ -330,11 +331,11 @@ QString KgpgKey::encryptionStrength() const
             // check if there is one that is not
             if (k.trust() > TRUST_EXPIRED)
                 return _describe_key_strength(k.algorithm(), k.size(), k.curve());
-            if (enc == Q_NULLPTR)
+            if (enc == nullptr)
                 enc = &k;
         }
     }
-    if (enc != Q_NULLPTR)
+    if (enc != nullptr)
         return _describe_key_strength(enc->algorithm(), enc->size(), enc->curve());
     return QString("");
 }
@@ -415,8 +416,11 @@ KgpgKey& KgpgKey::operator=(const KgpgKey &other)
 KgpgKeyList::operator QStringList() const
 {
     QStringList res;
-    foreach(const KgpgKey &key, *this)
+    res.reserve(count());
+
+    for (const KgpgKey &key : *this)
         res << key.fullId();
+
     return res;
 }
 
