@@ -19,12 +19,10 @@
 #define KGPGEDITOR_H
 
 #include <KXmlGuiWindow>
-#include <KUrl>
-
-#include <kgpgcompiler.h>
+#include <QUrl>
 
 class KToggleAction;
-class KAction;
+class QAction;
 class KFind;
 
 class KgpgTextEdit;
@@ -39,10 +37,10 @@ class KgpgEditor : public KXmlGuiWindow
 
     KgpgEditor() Q_DECL_EQ_DELETE;
 public:
-    KgpgEditor(KeysManager *parent, KGpgItemModel *model, Qt::WFlags f);
+    KgpgEditor(KeysManager *parent, KGpgItemModel *model, Qt::WindowFlags f);
     ~KgpgEditor();
 
-    void openEncryptedDocumentFile(const KUrl& url);
+    void openEncryptedDocumentFile(const QUrl &url);
 
     KgpgTextEdit * const m_editor;
     KRecentFilesAction *m_recentfiles;
@@ -52,7 +50,7 @@ signals:
     void openConfigDialog();
 
 public slots:
-    void openDocumentFile(const KUrl& url, const QString &encoding = QString());
+    void openDocumentFile(const QUrl &url, const QString &encoding = QString());
     void slotSetFont(QFont myFont);
     void closeWindow();
 
@@ -93,10 +91,10 @@ private slots:
 
     // Signing menu
     void slotPreSignFile();
-    void slotSignFile(const KUrl &url);
-    void slotSignFileFin();
+    void slotSignFile(const QUrl &url);
+    void slotSignFileFin(int);
     void slotPreVerifyFile();
-    void slotVerifyFile(const KUrl &url);
+    void slotVerifyFile(const QUrl &url);
     void slotCheckMd5();
     void importSignatureKey(const QString &id, const QString &fileName);
 
@@ -112,18 +110,18 @@ private slots:
 
     void slotLibraryDone();
 
-    void slotDownloadKeysFinished(QStringList ids);
+    void slotDownloadKeysFinished(const QStringList &ids);
 
 private:
     QString m_textencoding;
 
     KToggleAction *m_encodingaction;
-    KAction *m_editundo;
-    KAction *m_editredo;
-    KAction *m_editcopy;
-    KAction *m_editcut;
+    QAction *m_editundo;
+    QAction *m_editredo;
+    QAction *m_editcopy;
+    QAction *m_editcut;
     KFind *m_find;
-    KUrl m_docname;
+    QUrl m_docname;
 
     bool m_textchanged;		//< text was changed since last save
     bool m_emptytext;		//< this was not saved to a file ever
