@@ -9,43 +9,53 @@
 
 #include "kgpgmd5widget.h"
 
-#include <QHBoxLayout>
-#include <QClipboard>
-#include <QLabel>
+#include <QApplication>
+#include <QCryptographicHash>
 #include <QFile>
+#include <QClipboard>
+#include <QHBoxLayout>
+#include <QLabel>
+#include <QLineEdit>
 
-#include <KApplication>
 #include <KMessageBox>
-#include <KLineEdit>
-#include <KLocale>
-#include <KCodecs>
+#include <KLocalizedString>
 #include <KLed>
+#include <KConfigGroup>
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <QVBoxLayout>
 
 
-Md5Widget::Md5Widget(QWidget *parent, const KUrl &url)
-         : KDialog(parent)
+Md5Widget::Md5Widget(QWidget *parent, const QUrl &url)
+         : QDialog(parent)
 {
     setWindowTitle(i18n("MD5 Checksum"));
-    setButtons(Apply | Close);
-    setDefaultButton(Close);
-    setButtonText(Apply, i18n("Compare MD5 with Clipboard"));
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close|QDialogButtonBox::Apply);
+    QWidget *mainWidget = new QWidget(this);
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    setLayout(mainLayout);
+    mainLayout->addWidget(mainWidget);
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &Md5Widget::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &Md5Widget::reject);
+    buttonBox->button(QDialogButtonBox::Close)->setDefault(true);
+    buttonBox->button(QDialogButtonBox::Apply)->setText(i18n("Compare MD5 with Clipboard"));
 
     QFile f(url.path());
-    KMD5 checkfile;
+    QCryptographicHash checkfile(QCryptographicHash::Md5);
 
     if (f.open(QIODevice::ReadOnly)) {
-	checkfile.update(f);
+	checkfile.addData(&f);
 	f.close();
     }
 
-    m_md5sum = QLatin1String( checkfile.hexDigest().constData() );
+    m_md5sum = QLatin1String( checkfile.result() );
 
     QWidget *page = new QWidget(this);
 
     QLabel *firstlabel = new QLabel(page);
     firstlabel->setText(i18n("MD5 sum for <b>%1</b> is:", url.fileName()));
 
-    KLineEdit *md5lineedit = new KLineEdit(m_md5sum, page);
+    QLineEdit *md5lineedit = new QLineEdit(m_md5sum, page);
     md5lineedit->setReadOnly(true);
 
     m_led = new KLed(QColor(80, 80, 80), KLed::Off, KLed::Sunken, KLed::Circular, page);
@@ -63,21 +73,20 @@ Md5Widget::Md5Widget(QWidget *parent, const KUrl &url)
     ledlayout->addWidget(m_label);
 
     QVBoxLayout *dialoglayout = new QVBoxLayout(page);
-    dialoglayout->setMargin(marginHint());
-    dialoglayout->setSpacing(spacingHint());
     dialoglayout->addWidget(firstlabel);
     dialoglayout->addWidget(md5lineedit);
     dialoglayout->addLayout(ledlayout);
     dialoglayout->addStretch();
 
-    setMainWidget(page);
+    mainLayout->addWidget(page);
+    mainLayout->addWidget(buttonBox);
 
-    connect(this, SIGNAL(applyClicked()), this, SLOT(slotApply()));
+    connect(buttonBox->button(QDialogButtonBox::Apply), &QPushButton::clicked, this, &Md5Widget::slotApply);
 }
 
 void Md5Widget::slotApply()
 {
-    QString text = KApplication::clipboard()->text().remove(QLatin1Char( ' ' ));
+    QString text = qApp->clipboard()->text().remove(QLatin1Char( ' ' ));
     if (!text.isEmpty())
     {
         if (text.length() != m_md5sum.length())
