@@ -102,7 +102,7 @@ public:
 	void setOutputProcess(QProcess *outp);
 	/**
 	 * @brief set the transaction the output is sent to
-	 * @param outd transaction to send output to
+	 * @param outt transaction to send output to
 	 */
 	void setOutputTransaction(KGpgTransaction *outt);
 	/**
@@ -122,8 +122,8 @@ public:
 	const QByteArray &getOutputData() const;
 
 protected:
-	virtual bool preStart() Q_DECL_OVERRIDE;
-	virtual bool nextLine(const QString &line) Q_DECL_OVERRIDE;
+	bool preStart() Q_DECL_OVERRIDE;
+	bool nextLine(const QString &line) Q_DECL_OVERRIDE;
 
 private:
 	QStringList m_keyids;
